==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/RangeAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import { Array_$type, typeCast, runOn, markType } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Polyline } from "igniteui-react-core";
import { Polygon } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { isNaN_ } from "igniteui-react-core";
import { RangeCategorySeriesView } from "./RangeCategorySeriesView";
/**
 * @hidden
 */
export let RangeAreaSeries = /*@__PURE__*/ (() => {
    class RangeAreaSeries extends HorizontalRangeCategorySeries {
        cg() {
            return new RangeAreaSeriesView(this);
        }
        o0(a) {
            super.o0(a);
            this.yk = a;
        }
        get_d9() {
            return true;
        }
        get_d8() {
            return true;
        }
        yl(a, b, c, d) {
            if (isNaN_(b.x) || isNaN_(b.y)) {
                return false;
            }
            if (isNaN_(c.x) || isNaN_(c.y)) {
                return false;
            }
            if ((a.y <= b.y && a.y >= c.y)) {
                return true;
            }
            return false;
        }
        f4(a, b) {
            if (this.f3(a, b)) {
                return true;
            }
            if (this.ud(a, b)) {
                return true;
            }
            return false;
        }
        constructor() {
            super();
            this.ab = RangeAreaSeries.$;
        }
        preferredCategoryMode(a) {
            return 0;
        }
        nj(a, b) {
            super.nj(a, b);
            let c = b;
            c.c6();
        }
        w5(a, b) {
            super.w5(a, b);
            let c = a.f.count;
            let d = new List$1(Array_$type, 2, c);
            for (let e = 0; e < c; e++) {
                let f = a.f._inner[e];
                let g = new Array(4);
                g[0] = f[0];
                g[1] = f[1];
                let h = a.f._inner[a.f.count - 1 - e];
                g[2] = h[0];
                g[3] = h[2];
                d.add(g);
            }
            let i = typeCast(RangeAreaSeriesView.$, b);
            let j = this.getEffectiveViewport1(i);
            this.vu.a2(this, this.we(), runOn(this, this.vf), this.wn(b), this.wo(b));
            let k = false;
            let l = this.vu.b;
            if (l != null) {
                k = true;
            }
            if (k) {
                let m = new ScalerParams(0, b.by, b.bx, this.xAxis.ch, j);
                this.w1(d, -1, this.lowColumn.count, this.xAxis, m, b.q);
            }
            let n = i.df;
            let o = i.dg;
            let p = i.da;
            this.vu.ad(n, true, false, true, true);
            this.vu.ad(o, true, false, true, true);
            this.vu.ad(p, false, true, false, false);
            if (b.cy(a)) {
                i.c7(a.f.count, d, false);
                b.c1(a);
            }
            i.da._opacity = this.vu.j * this.hf;
        }
        get useHighMarkerFidelity() {
            return this.wi;
        }
    }
    RangeAreaSeries.$t = /*@__PURE__*/ markType(RangeAreaSeries, 'RangeAreaSeries', HorizontalRangeCategorySeries.$);
    return RangeAreaSeries;
})();
/**
 * @hidden
 */
export let RangeAreaSeriesView = /*@__PURE__*/ (() => {
    class RangeAreaSeriesView extends RangeCategorySeriesView {
        constructor(a) {
            super(a);
            this.c5 = null;
            this.dd = new Polyline();
            this.c9 = new Polygon();
            this.de = new Polyline();
            this.dc = new Polyline();
            this.db = new Polyline();
            this.c8 = new Polygon();
            this.c5 = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.c5.ua = 1;
            }
        }
        get df() {
            return this.dd;
        }
        get da() {
            return this.c9;
        }
        get dg() {
            return this.de;
        }
        c6() {
            this.c9.an.clear();
            this.dd.an.clear();
            this.de.an.clear();
        }
        c7(a, b, c) {
            this.c4(this.dd, this.c9, this.de, a, b, c);
            this.as();
        }
        be() {
            super.be();
            this.db.an = this.dd.an;
            this.dc.an = this.de.an;
            this.c8.an = this.c9.an;
            let a = this.br();
            this.db._stroke = a;
            this.db.ad = this.e.hk + 3;
            this.dc._stroke = a;
            this.dc.ad = this.e.hk + 3;
            this.c8._fill = a;
            this.c8._opacity = 1;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.u(this.c8);
                    a.v(this.db);
                    a.v(this.dc);
                }
                else {
                    a.u(this.c9);
                    a.v(this.dd);
                    a.v(this.de);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.a9.exportPolylineData(a, this.dd, "lowerShape", ["Lower"]);
            this.e.a9.exportPolylineData(a, this.de, "upperShape", ["Upper", "Main"]);
            this.e.a9.exportPolygonData(a, this.c9, "fillShape", ["Fill"]);
        }
    }
    RangeAreaSeriesView.$t = /*@__PURE__*/ markType(RangeAreaSeriesView, 'RangeAreaSeriesView', RangeCategorySeriesView.$);
    return RangeAreaSeriesView;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/RangeAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import { Array_$type, typeCast, runOn, markType } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Polyline } from "igniteui-react-core";
import { Polygon } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { ChartSelection } from "./ChartSelection";
import { isNaN_ } from "igniteui-react-core";
import { RangeCategorySeriesView } from "./RangeCategorySeriesView";
/**
 * @hidden
 */
export let RangeAreaSeries = /*@__PURE__*/ (() => {
    class RangeAreaSeries extends HorizontalRangeCategorySeries {
        bj() {
            return new RangeAreaSeries();
        }
        cr() {
            return new RangeAreaSeriesView(this);
        }
        qz(a) {
            super.qz(a);
            this.abv = a;
        }
        get_eu() {
            return true;
        }
        get_et() {
            return true;
        }
        abw(a, b, c, d) {
            if (isNaN_(b.x) || isNaN_(b.y)) {
                return false;
            }
            if (isNaN_(c.x) || isNaN_(c.y)) {
                return false;
            }
            if ((a.y <= b.y && a.y >= c.y)) {
                return true;
            }
            return false;
        }
        gv(a, b) {
            if (this.gu(a, b)) {
                return true;
            }
            if (this.xc(a, b)) {
                return true;
            }
            return false;
        }
        constructor() {
            super();
            this.ab = RangeAreaSeries.$;
        }
        preferredCategoryMode(a) {
            return 0;
        }
        o4(a, b) {
            super.o4(a, b);
            let c = b;
            c.c8();
        }
        aaf(a, b) {
            super.aaf(a, b);
            let c = a.f.count;
            let d = new List$1(Array_$type, 2, c);
            for (let e = 0; e < c; e++) {
                let f = a.f._inner[e];
                let g = new Array(4);
                g[0] = f[0];
                g[1] = f[1];
                let h = a.f._inner[a.f.count - 1 - e];
                g[2] = h[0];
                g[3] = h[2];
                d.add(g);
            }
            let i = typeCast(RangeAreaSeriesView.$, b);
            let j = this.getEffectiveViewport1(i);
            this.yx.a2(this, this.zh(), runOn(this, this.yh), this.zq(b), this.zr(b));
            let k = false;
            let l = this.yx.b;
            if (l != null) {
                k = true;
            }
            if (k) {
                let m = new ScalerParams(0, b.by, b.bx, this.xAxis.ch, j);
                this.aab(d, -1, this.lowColumn.count, this.xAxis, m, b.q, -1);
            }
            let n = i.dh;
            let o = i.di;
            let p = i.dc;
            this.yx.ad(n, true, false, true, true);
            this.yx.ad(o, true, false, true, true);
            this.yx.ad(p, false, true, false, false);
            if (b.c0(a)) {
                i.c9(a.f.count, d, false);
                b.c3(a);
            }
            i.dc._opacity = this.yx.j * this.h8;
        }
        p1(a, b, c) {
            this.z7(a, b, c, this.yo, 1);
        }
        ak(a, b) {
            let c = new List$1(ChartSelection.$, 0);
            this.p1(a, c, b);
            return c.toArray();
        }
        get useHighMarkerFidelity() {
            return this.zl;
        }
    }
    RangeAreaSeries.$t = /*@__PURE__*/ markType(RangeAreaSeries, 'RangeAreaSeries', HorizontalRangeCategorySeries.$);
    return RangeAreaSeries;
})();
/**
 * @hidden
 */
export let RangeAreaSeriesView = /*@__PURE__*/ (() => {
    class RangeAreaSeriesView extends RangeCategorySeriesView {
        constructor(a) {
            super(a);
            this.c7 = null;
            this.df = new Polyline();
            this.db = new Polygon();
            this.dg = new Polyline();
            this.de = new Polyline();
            this.dd = new Polyline();
            this.da = new Polygon();
            this.c7 = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.c7.w5 = 1;
            }
        }
        get dh() {
            return this.df;
        }
        get dc() {
            return this.db;
        }
        get di() {
            return this.dg;
        }
        c8() {
            this.db.an.clear();
            this.df.an.clear();
            this.dg.an.clear();
        }
        c9(a, b, c) {
            this.c6(this.df, this.db, this.dg, a, b, c);
            this.as();
        }
        be() {
            super.be();
            this.dd.an = this.df.an;
            this.de.an = this.dg.an;
            this.da.an = this.db.an;
            let a = this.br();
            this.dd._stroke = a;
            this.dd.ad = this.e.id + 3;
            this.de._stroke = a;
            this.de.ad = this.e.id + 3;
            this.da._fill = a;
            this.da._opacity = 1;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.u(this.da);
                    a.v(this.dd);
                    a.v(this.de);
                }
                else {
                    a.u(this.db);
                    a.v(this.df);
                    a.v(this.dg);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.bc.exportPolylineData(a, this.df, "lowerShape", ["Lower"]);
            this.e.bc.exportPolylineData(a, this.dg, "upperShape", ["Upper", "Main"]);
            this.e.bc.exportPolygonData(a, this.db, "fillShape", ["Fill"]);
        }
    }
    RangeAreaSeriesView.$t = /*@__PURE__*/ markType(RangeAreaSeriesView, 'RangeAreaSeriesView', RangeCategorySeriesView.$);
    return RangeAreaSeriesView;
})();
